@@ -6,10 +6,10 @@
 #include "colorlib.h"  // For the 'colorlist'
 
 // The red, green and blue triple of the current color.
-int rgb[3];
+extern int rgb[3];
 
 // The picklist containing all of the colors from the file
-Widget list;
+extern Widget list;
 
 // Initialize the widgets
 void Init(Widget);
